import unittest
import pandas as pd

from context import measprocess as mpc

class TestLinkFrames(unittest.TestCase):
    def setUp(self):
        #Init the Dummy Example
        A = pd.DataFrame({'ref':[10,20,30, 31, 5], 'info': [5, 4, 1, 2, 1]})
        A.index = range(2, 7)

        B = pd.DataFrame({'ref':[15,17,27, 4], 'info': [1, 2, 3, 4], 'yo': [4, 6, 1, 8]})
        B.index = range(9, 13)

        self._A, self._B = A, B

        self._meas = pd.read_csv("tests/example_files/scanner_1/measurement_example.csv", index_col=0)
        self._gps = pd.read_csv("tests/example_files/scanner_1/gps_example.csv", index_col=0)

    def test_multiindex_dummy(self):
        combined = mpc.preprocess.link_dataframes(self._A, self._B, ref_col="ref")

        self.assertTrue(
            all(self._A == combined['A'])
        )

    def test_real_numeric_type(self):
        with self.assertRaises(ValueError):
            combined = mpc.preprocess.link_dataframes(
                self._meas,
                self._gps,
                "Datetime",
                unique_col="PCI"
            )

    def test_multiindex_real(self):
        meas, gps = self._meas, self._gps
        meas['Datetime'] = pd.to_datetime(meas['Datetime'])
        gps['Datetime'] = pd.to_datetime(gps['Datetime'])

        print(gps['Datetime'])

        combined = mpc.preprocess.link_dataframes(
            meas,
            gps,
            "Datetime",
            unique_col="PCI"
        )

        self.assertTrue(
            all(meas == combined['A'])
        )

    def test_duplicates_dummy(self):
        with self.assertRaises(ValueError):
            mpc.preprocess.link_dataframes(self._A, self._B, ref_col="info")

if __name__ == '__main__':
    unittest.main()
